@@ -12,6 +12,9 @@ global_vars = {}
 global local_vars
 local_vars = {}
 
+global dynamic_cell_output
+dynamic_cell_output = ""
+
 """
 Structure Guide
 
@@ -121,6 +124,9 @@ class Cell():
         global_vars.update(gcopy)
         local_vars.update(lcopy)
 
+        global dynamic_cell_output
+        dynamic_cell_output += self.name + ":\n" + self.output + "\n\n"
+
     def __str__(self):
         return self.name + "\n\n" + "```\n" + self.content + "```\n"
 
@@ -140,6 +146,8 @@ class Graph:
         # TextIO object
         self.ti = TextIO()
 
+        self.executing = False
+
     def get_lookup_table(self):
         return {idx: moniker for moniker, idx in
                 zip(list(self.names_to_indeces.keys()), list(self.names_to_indeces.values()))}
@@ -341,7 +349,14 @@ class Graph:
                 txt.write(std_file_out)
 
     def bfs_traversal_execute(self, stdout="internal", output_filename="stdout.txt"):
+        if len(self.get_all_cells_edges()[0]) == 0:
+            return
+
         std_file_out = ""
+        global dynamic_cell_output
+        dynamic_cell_output = ""
+
+        self.executing = True
 
         root_cell = self.get_cell("", 0)
         root_cell.stdout = stdout
@@ -381,6 +396,8 @@ class Graph:
             with open(output_filename, 'w') as txt:
                 txt.write(std_file_out)
 
+        self.executing = False
+
     def save_graph(self, filename):
         txtout = ""
 
@@ -397,7 +414,7 @@ class Graph:
                 fill_with_code = "n\n"
             temp_text = "cell " + c.name + " " + c.content_type + " " + fill_with_code
             if fill_with_code == "y:\n":
-                temp_text += c.content + ";\n"
+                temp_text += c.content + "\n;\n"
 
             txtout += temp_text
 
@@ -423,7 +440,7 @@ class Graph:
                 fill_with_code = "n\n"
             temp_text = "cell " + c.name + " " + c.content_type + " " + fill_with_code
             if fill_with_code == "y:\n":
-                temp_text += c.content + ";\n"
+                temp_text += c.content + "\n;\n"
 
             txtout += temp_text
 
@@ -441,7 +458,7 @@ class Interpreter:
         # Graph object
         self.graph = Graph()
         # Assume live input first
-        self.input_type = "live"
+        self.input_type = "file"
         # This will be set if the user executes a .satx file
         self.file = None
         # This determines whether or not stdout gets sent to an external textbox
@@ -461,6 +478,76 @@ class Interpreter:
         except Exception as e:
             print(e)
 
+    def run_string(self, content):
+        self.file = content
+        self.input_type = "file"
+
+        print(content)
+
+        while len(content) > 0:
+            command = content.pop(0).split(" ")
+            print(command)
+
+            if len(command) == 0 or command == '':
+                continue
+
+            elif command[0] == "help":
+                print(self.help_menu())
+
+            elif command[0] == "quit":
+                break
+
+            elif command[0] == "cell":
+                self.create_cell(command)
+
+            elif command[0] == "edit":
+                self.edit_cell(command)
+
+            elif command[0] == "rename":
+                self.rename_cell(command)
+
+            elif command[0] == "remove":
+                self.remove_cell(command)
+
+            elif command[0] == "link":
+                self.link(command)
+
+            elif command[0] == "sever":
+                self.sever(command)
+
+            elif command[0] == "merge":
+                self.merge(command)
+
+            elif command[0] == "swap":
+                self.swap(command)
+
+            elif command[0] == "execute":
+                self.execute(command)
+
+            elif command[0] == "display":
+                self.display(command)
+
+            elif command[0] == "list":
+                self.list_cells()
+
+            elif command[0] == "stdout":
+                self.set_stdout(command)
+
+            elif command[0] == "reset_runtime":
+                self.reset_runtime()
+
+            elif command[0] == "reset_graph":
+                self.reset_graph()
+
+            elif command[0] == "save":
+                self.save_graph(command)
+
+            elif ".satx" in command[0]:
+                self.run_file(command)
+
+            else:
+                print("Syntax error: command \"" + command[0] + "\" not recognized.")
+
     def read_input(self):
         # Read input from stdin or external file. Returns list of command params.
         if self.input_type == "live" or len(self.file) == 0:
@@ -545,7 +632,6 @@ class Interpreter:
                 content = ti.text_input().strip()
 
         self.graph.add_cell(Cell(name, content_type, content))
-        print(self.list_cells())
 
     def edit_cell(self, command):
         """
@@ -716,7 +802,6 @@ class Interpreter:
             return
         self.stdout = command[1]
 
-    @staticmethod
     def reset_runtime(self):
         # Delete all runtime variables
         global global_vars
@@ -724,10 +809,15 @@ class Interpreter:
         global local_vars
         local_vars = {}
 
-    def reset_graph(self):
-        confirm = input("Are you sure you want to reset the graph? This will delete all nodes and variables. (y/n) ")
-        if "y" in confirm:
+    def reset_graph(self, ask=True):
+        if(ask):
+            confirm = input("Are you sure you want to reset the graph? This will delete all nodes and variables. (y/n) ")
+            if "y" in confirm:
+                self.graph = Graph()
+                self.reset_runtime()
+        else:
             self.graph = Graph()
+            self.reset_runtime()
 
     def save_graph(self, command):
         """
@@ -738,16 +828,13 @@ class Interpreter:
             return
         self.graph.save_graph(command[1])
 
-
 interpreter = Interpreter()
 
-
 def new_name():
     letters_and_digits = string.ascii_letters + string.digits
     result_str = ''.join((random.choice(letters_and_digits) for i in range(16)))
     return result_str
 
-
 def create_app(test_config=None):
     # create and configure the app
     app = Flask(__name__, instance_relative_config=True)
@@ -774,9 +861,17 @@ def create_app(test_config=None):
     def index():
         return render_template("index.html")
 
-    @app.route("/style.css")
-    def syle_css():
-        return render_template("style.css")
+    @app.route("/canvas.html")
+    def canvas():
+        return render_template("canvas.html")
+
+    @app.route("/index_style.css")
+    def index_style():
+        return render_template("index_style.css")
+
+    @app.route("/canvas_style.css")
+    def canvas_style():
+        return render_template("canvas_style.css")
 
     @app.route("/script.js")
     def script_js():
@@ -808,8 +903,6 @@ def create_app(test_config=None):
         cell_name = data['name'].strip()
         content = data['content'].strip()
 
-        print(cell_name + " " + content)
-
         interpreter.set_cell_contents(['edit_cell', cell_name, content])
 
         return "true"
@@ -856,7 +949,7 @@ def create_app(test_config=None):
         first = data['first'].strip()
         second = data['second'].strip()
 
-        if (first == second):
+        if(first == second):
             return "false"
 
         interpreter.link(['link', first, second])
@@ -910,4 +1003,41 @@ def create_app(test_config=None):
             return "true"
         return "false"
 
-    return app
+    @app.route("/dynamic_cell_output/", methods=["GET"])
+    def get_dynamic_cell_output():
+        global dynamic_cell_output
+        if interpreter.graph.executing:
+            return render_template("dynamic_cell_output.html", dynamic_cell_output=dynamic_cell_output)
+        print(dynamic_cell_output)
+        return "done_executing;" + dynamic_cell_output
+
+    @app.route("/load_graph/", methods=["POST"])
+    def load_graph():
+        if(request.get_json()['load_from_file']):
+            interpreter.reset_graph(False)
+            raw = request.get_json()['file_contents']
+            content = raw.split("\n")
+            interpreter.run_string(content)
+
+        cell_names = interpreter.graph.get_all_cells_edges()[0]
+        links = interpreter.graph.get_all_cells_edges()[1]
+
+        names = []
+        contents = []
+        content_types = []
+        outputs = []
+
+        for cn in cell_names:
+            cell = interpreter.graph.get_cell(cn)
+            names.append(cn)
+            contents.append(cell.content)
+            content_types.append(cell.content_type)
+            outputs.append(cell.output)
+
+        return {'names': names,
+                'contents': contents,
+                'content_types': content_types,
+                'links': links}
+
+
+    return app
\ No newline at end of file
